@@ -11,8 +11,9 @@ import click
 from distutils import dir_util
 from distutils import file_util
 
+from hflossk.version import __version__
 from hflossk.cli.util import year, season
-from hflossk.cli.openshift import push_to_openshift
+from hflossk.cli.openshift import push_to_openshift, is_clean
 
 
 @click.group()
@@ -35,19 +36,19 @@ def new():
     # \u2714 is a check mark
     # \u2717 is an x
     # TODO: include default README with instructions for starting your course
-    print(u'\u2714 Glorious README')
+    click.echo(u'\u2714 Glorious README')
 
     source_dir = os.path.split(__file__)[0].replace('cli', '')
 
     static_dir = os.path.join(os.getcwd(), 'static')
     dir_util.copy_tree(source_dir + 'static', static_dir, update=True)
 
-    print(u'\u2714 CSS/Javascript for browser art')
+    click.echo(u'\u2714 CSS/Javascript for browser art')
 
     templates_dir = os.path.join(os.getcwd(), 'templates')
     dir_util.copy_tree(source_dir + 'templates', templates_dir, update=True)
 
-    print(u'\u2714 Starter Mako templates for great good')
+    click.echo(u'\u2714 Starter Mako templates for great good')
 
     yamls_dir = os.path.join(source_dir, 'yamls')
 
@@ -60,17 +61,19 @@ def new():
 
     file_util.copy_file(os.path.join(yamls_dir, 'site.yaml'),
                         os.getcwd(), update=True)
+    file_util.copy_file(os.path.join(yamls_dir, 'oer.yaml'),
+                        os.getcwd(), update=True)
     file_util.copy_file(os.path.join(yamls_dir, 'schedule.yaml'),
                         os.getcwd(), update=True)
 
-    print(u'\u2714 Starter yaml files for data driven education')
+    click.echo(u'\u2714 Starter yaml files for data driven education')
 
 
 @cli.command()
 def version():
-    print("You are using hflossk version 0.5.4")
-    print("Get more information at "
-          "https://github.com/decause/hflossk")
+    click.echo("You are using hflossk version {}".format(__version__))
+    click.echo("Get more information at "
+               "https://github.com/decause/hflossk")
 
 
 @cli.command(short_help="Push this to openshift. Requires "
@@ -80,6 +83,13 @@ def version():
 @click.option('--remote', help="Openshift git URL")
 def openshift(verbose, remote):
     site_yaml = os.path.join(os.getcwd(), 'site.yaml')
+
+    is_clean() or click.confirm(
+        "You have uncommitted changes. Changes that aren't committed "
+        "won't be pushed to openshift.\n"
+        "Do you want to continue?", abort=True
+    )
+
     if remote is None and os.path.isfile(site_yaml):
         with open(site_yaml, 'r') as site:
             s = yaml.load(site)
